@@ -29,13 +29,17 @@ class TarFile(tarfile.TarFile):
         if fileobj is not None:
             fileobj = FileWrapper(fileobj, self.get_progress(tarinfo.size, desc=tarinfo.name))
         result = super(TarFile, self).addfile(tarinfo, fileobj)
-        self._progress_callback.close()
+        self.close_progress()
         return result
 
+    def close_progress(self):
+        if self._progress_callback is not None:
+            self._progress_callback.close()
+
     def extractall(self, path=".", members=None, **kwargs):
         original = self.fileobj
         try:
-            stats = os.fstat(self.fileobj.fileno())
+            stats = os.fstat(self.fileobj)
             self.fileobj = FileWrapper(self.fileobj, self.get_progress(stats.st_size, desc=self.name))
         except Exception as e:
             logging.warning(f"extractall error:{e}")
@@ -43,7 +47,7 @@ class TarFile(tarfile.TarFile):
 
         result = super(TarFile, self).extractall(path, members)
         self.fileobj = original
-        self._progress_callback.close()
+        self.close_progress()
         return result
 
     def extract(self, member, path="", **kwargs):
@@ -53,8 +57,7 @@ class TarFile(tarfile.TarFile):
     def extractfile(self, member):
         fileobj = super(TarFile, self).extractfile(member)
         if fileobj is not None:
-            fileobj = FileWrapper(fileobj, self.get_progress(member.size, desc=member.name))        
-
+            fileobj = FileWrapper(fileobj, self.get_progress(member.size, desc=member.name))
 
 
 class FileWrapper(object):
